@@ -1,7 +1,7 @@
 #coding: utf-8
 from __future__ import with_statement
-from fabric.api import run, settings
-from fab_deploy.commands import mysqldump
+from fabric.api import run, settings, env
+from fab_deploy.mysql import mysqldump
 from fab_deploy.utils import inside_project
 
 @inside_project
@@ -10,7 +10,9 @@ def manage(command):
 
 def migrate(params='', do_backup=True):
     if do_backup:
-        mysqldump('hosting/backups/before-migrate')
+        backup_dir = env.conf['ENV_DIR']+'/var/backups/before-migrate'
+        run('mkdir -p '+ backup_dir)
+        mysqldump(backup_dir)
     manage('migrate --noinput %s' % params)
 
 def syncdb(params=''):
