@@ -1,7 +1,7 @@
 from functools import wraps
 from fabric.context_managers import prefix, cd
 from fabric.contrib.files import upload_template
-from fabric.api import env
+from fabric.api import env, run
 
 def run_as(user):
     def decorator(func):
@@ -15,34 +15,32 @@ def run_as(user):
         return inner
     return decorator
 
-def upload_hosting_template(name, to=None):
-    base_dir = "%s/hosting/" % env.conf['SRC_DIR']
+def upload_config_template(name, to=None):
     if to is None:
-        to = base_dir + 'generated/%s' % name
-    upload_template('./hosting/templates/'+name, to, env.conf, True)
+        base_dir = env.conf['ENV_DIR'] + "/etc/"
+        run('mkdir -p ' + base_dir)
+        to = base_dir + name
+    upload_template('./config_templates/' + name, to, env.conf, True)
 
 def update_env():
     HOME_DIR = '/home/%s' % env.user
-    ENV_BASE, SRC_BASE = 'envs', 'src'
 
     if 'INSTANCE_NAME' not in env.conf:
         env.conf['INSTANCE_NAME'] = env.user
 
-    if 'SERVER_NAME' not in env.conf:
-        env.conf['SERVER_NAME'] = env.hosts[0]
-
     defaults = dict(
         HG_BRANCH = 'default',
         DB_NAME = env.conf['INSTANCE_NAME'],
+        DB_USER = 'root',
         PROCESSES = 1,
         THREADS = 5,
         HOME_DIR = HOME_DIR,
-        ENV_BASE = ENV_BASE,
-        SRC_BASE = SRC_BASE,
-        ENV_DIR = HOME_DIR + '/' + ENV_BASE + '/' + env.conf['INSTANCE_NAME'],
-        SRC_DIR = HOME_DIR + '/' + SRC_BASE + '/' + env.conf['INSTANCE_NAME'],
+        ENV_DIR = HOME_DIR + '/envs/' + env.conf['INSTANCE_NAME'],
+        SRC_DIR = HOME_DIR + '/src/' + env.conf['INSTANCE_NAME'],
         USER = env.user,
         HOST = env.hosts[0],
+        SERVER_NAME = env.hosts[0],
+        SERVER_ADMIN = 'example@example.com',
     )
     defaults.update(env.conf)
     env.conf = defaults
@@ -89,3 +87,9 @@ def inside_project(func):
             with virtualenv():
                 return func(*args, **kwargs)
     return inner
+
+@inside_project
+def delete_pyc():
+    """ Deletes *.pyc files from project source dir """
+    run("find . -name '*.pyc' -delete")
+
